# Curso FIAP - Aula Fundamental Python

A simple example library.

## Installation

```sh
pip install curso_fiap_dev_ia
```

## Usage

```python
from curso_fiap_dev_ia import hello_world

print(hello_world())
```
